<img src="https://discordapp.com/assets/e05ead6e6ebc08df9291738d0aa6986d.png" align="right" />

# Piscord

Piscord est un framework python permettant de communiquer avec l'api Discord.

Il simplifie notamment la création de bot interagissant avec un server Web.
Il permet ainsi de faire beaucoup plus facilement diverses choses comme des panel de controle de bot.

Ainsi, dans tout les exemples, Piscord est utilisé avec [SAPAS](https://github.com/Astremy/SAPAS).

Comment l'utiliser :
Il suffit de le mettre dans le dossier de votre projet et d'ensuite l'importer.

Modules utilisés :
- asyncio
- json
- aiohttp
- threading

Auteur : Astremy

Discord : [Piscord](https://discord.gg/U9X7XzP)

This project is licensed under the terms of the MIT license : [License](https://github.com/Astremy/Piscord/blob/master/LICENSE.md)
